@@ -2,8 +2,7 @@ import argparse
 
 from .pycharm_remote_debugger import PycharmRemoteDebugger
 
-print("^"*10)
-print("")
+
 def main():
     parser = argparse.ArgumentParser(description="Pycharm remote debugger")
     parser.add_argument("-r", "--remote", help="Remote machine address", type=str, default="")
