@@ -9,6 +9,12 @@ import pydevd_pycharm
 import waiting
 
 log = logging.getLogger("pycharm_remote_debugger")
+log.setLevel(logging.DEBUG)
+handler = logging.StreamHandler(sys.stdout)
+handler.setLevel(logging.DEBUG)
+formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+handler.setFormatter(formatter)
+log.addHandler(handler)
 
 
 class PycharmRemoteDebugger:
